@@ -1,4 +1,5 @@
 ### R code from vignette source 'VModelMap.Rnw'
+### Encoding: ISO8859-1
 
 ###################################################
 ### code chunk number 1: Ex1 set options
@@ -1581,349 +1582,7 @@ par(opar)
 
 
 ###################################################
-### code chunk number 91: Ex4 Define model type
-###################################################
-model.type <- "SGB"
-
-
-###################################################
-### code chunk number 92: Ex4 Define training and test files
-###################################################
-qdatafn <- "VModelMapData.csv"
-
-
-###################################################
-### code chunk number 93: Ex4 define folder
-###################################################
-folder <- getwd()
-
-
-###################################################
-### code chunk number 94: Ex4 Define model filename
-###################################################
-MODELfn.a    <- "VModelMapEx4a"
-MODELfn.b    <- "VModelMapEx4b"
-
-
-###################################################
-### code chunk number 95: Ex4 Define predictors
-###################################################
-predList <- c( "ELEV250",
-               "NLCD01_250",
-               "EVI2005097",
-               "NDV2005097",
-               "NIR2005097",
-               "RED2005097")
-predFactor <- c("NLCD01_250")
-
-
-###################################################
-### code chunk number 96: Ex4 Define response
-###################################################
-response.name.a <- "PINYON"
-response.name.b <- "SAGE"
-response.type <- "binary"
-
-
-###################################################
-### code chunk number 97: Ex4 set seed
-###################################################
-seed.a <- 42
-seed.b <- 43
-
-
-###################################################
-### code chunk number 98: Ex4 Define Identifier
-###################################################
-unique.rowname <- "ID"
-
-
-###################################################
-### code chunk number 99: Ex4 update raster LUT
-###################################################
-rastLUTfn   <- "VModelMapData_LUT.csv"
-rastLUTfn     <- read.table( rastLUTfn,
-                             header=FALSE,
-                             sep=",",
-                             stringsAsFactors=FALSE)
-rastLUTfn[,1] <- paste(folder,rastLUTfn[,1],sep="/")
-
-
-###################################################
-### code chunk number 100: Ex4 Create Model
-###################################################
-model.obj.ex4a <- model.build( model.type=model.type,
-                               qdata.trainfn=qdatafn,
-                               folder=folder,
-                               unique.rowname=unique.rowname,               
-                               MODELfn=MODELfn.a,
-                               predList=predList,
-                               predFactor=predFactor,
-                               response.name=response.name.a,
-                               response.type=response.type,
-                               seed=seed.a)
-           
-model.obj.ex4b <- model.build( model.type=model.type,
-                               qdata.trainfn=qdatafn,
-                               folder=folder,
-                               unique.rowname=unique.rowname,               
-                               MODELfn=MODELfn.b,
-                               predList=predList,
-                               predFactor=predFactor,
-                               response.name=response.name.b,
-                               response.type=response.type,
-                               seed=seed.b)
-
-
-###################################################
-### code chunk number 101: Ex4 Model Diagnostics
-###################################################
-model.pred.ex4a <- model.diagnostics( model.obj=model.obj.ex4a,
-                                      qdata.trainfn=qdatafn,
-                                      folder=folder,           
-                                      MODELfn=MODELfn.a,
-                                      unique.rowname=unique.rowname,
-                                      seed=44,
-                             # Model Validation Arguments
-                                      prediction.type="CV",
-                                      device.type=c("jpeg","pdf","postscript"),
-                                      cex=1.2,
-                                      na.action = "na.roughfix")
-           
-model.pred.ex4b <- model.diagnostics( model.obj=model.obj.ex4b,
-                                      qdata.trainfn=qdatafn,
-                                      folder=folder,           
-                                      MODELfn=MODELfn.b,
-                                      unique.rowname=unique.rowname,
-                                      seed=45,
-                              # Model Validation Arguments
-                                      prediction.type="CV",
-                                      device.type=c("jpeg","pdf","postscript"),
-                                      cex=1.2,
-                                      na.action = "na.roughfix")
-
-
-###################################################
-### code chunk number 102: Ex4 Optimal Threshold Table
-###################################################
-opt.thresh.a <- read.table( paste(MODELfn.a,"_pred_optthresholds.csv",sep=""),
-                            header=TRUE,
-                            sep=",",
-                            stringsAsFactors=FALSE)
-opt.thresh.a[,-1]<-signif(opt.thresh.a[,-1],2)
-
-opt.thresh.b <- read.table( paste(MODELfn.b,"_pred_optthresholds.csv",sep=""),
-                            header=TRUE,
-                            sep=",",
-                            stringsAsFactors=FALSE)
-opt.thresh.b[,-1]<-signif(opt.thresh.b[,-1],2)
-
-
-###################################################
-### code chunk number 103: Ex4a Optimal Threshold Table Show
-###################################################
-opt.thresh.a
-
-
-###################################################
-### code chunk number 104: Ex4b Optimal Threshold Table Show
-###################################################
-opt.thresh.b
-
-
-###################################################
-### code chunk number 105: Ex4CompImp
-###################################################
-
-opar <- par(mfrow=c(2,1),mar=c(3,3,3,3),oma=c(0,0,3,0))
-
-model.importance.plot( model.obj.1=model.obj.ex2a,
-                       model.obj.2=model.obj.ex4a,
-                       model.name.1="RF",
-                       model.name.2="SGB",
-                       sort.by="predList",
-                       predList=predList,
-                       scale.by="sum",
-                       main="Pinyon Presence",
-                       device.type="none",
-                       cex=0.9)
-                      
-model.importance.plot( model.obj.1=model.obj.ex2b,
-                       model.obj.2=model.obj.ex4b,
-                       model.name.1="RF",
-                       model.name.2="SGB",
-                       sort.by="predList",
-                       predList=predList,
-                       scale.by="sum",
-                       main="Sage Presence",
-                       device.type="none",
-                       cex=0.9)
-                       
-mtext("Variable Importance Comparison",side=3,line=0,cex=1.8,outer=TRUE)
-par(opar)
-
-
-###################################################
-### code chunk number 106: Ex4CompImpFig
-###################################################
-
-opar <- par(mfrow=c(2,1),mar=c(3,3,3,3),oma=c(0,0,3,0))
-
-model.importance.plot( model.obj.1=model.obj.ex2a,
-                       model.obj.2=model.obj.ex4a,
-                       model.name.1="RF",
-                       model.name.2="SGB",
-                       sort.by="predList",
-                       predList=predList,
-                       scale.by="sum",
-                       main="Pinyon Presence",
-                       device.type="none",
-                       cex=0.9)
-                      
-model.importance.plot( model.obj.1=model.obj.ex2b,
-                       model.obj.2=model.obj.ex4b,
-                       model.name.1="RF",
-                       model.name.2="SGB",
-                       sort.by="predList",
-                       predList=predList,
-                       scale.by="sum",
-                       main="Sage Presence",
-                       device.type="none",
-                       cex=0.9)
-                       
-mtext("Variable Importance Comparison",side=3,line=0,cex=1.8,outer=TRUE)
-par(opar)
-
-
-###################################################
-### code chunk number 107: Ex4 Interaction Plots
-###################################################
-ELEV<-c(1600,2100)
-NCLD<-c(30,80)
-
-for(j in ELEV){
-for(k in NCLD){
-      pred.means<-list(j,k)
-      names(pred.means)<-c("ELEV250","NLCD01_250")
-      model.interaction.plot( model.obj.ex4b,
-                              x="EVI2005097",
-                              y="NDV2005097",
-                              main=paste(response.name.b," (ELEV=",j,"  NCLD=",k,")",sep=""),
-                              plot.type="persp",
-                              device.type="pdf",
-                              pred.means=pred.means,
-                              theta=65,phi=25,
-                              MODELfn=paste(MODELfn.b,"ELEV",j,"NCLD",k,sep="_"),
-                              folder=folder)
-}}
-
-
-
-###################################################
-### code chunk number 108: Ex4 Produce Maps
-###################################################
-
-model.mapmake( model.obj=model.obj.ex4a,
-               folder=folder,           
-               MODELfn=MODELfn.a,
-               rastLUTfn=rastLUTfn)
-            
-
-model.mapmake( model.obj=model.obj.ex4b,
-               folder=folder,           
-               MODELfn=MODELfn.b,
-               rastLUTfn=rastLUTfn)
-
-
-
-###################################################
-### code chunk number 109: Ex4 define color sequence
-###################################################
-h=c(  seq(10,30,length.out=10),
-	    seq(31,40,length.out=10),
-    	seq(41,90,length.out=60),
-	    seq(91,100,length.out=10),
-	    seq(101,110,length.out=10))
-l =c( seq(25,40,length.out=10),
-	    seq(40,90,length.out=35),
-	    seq(90,90,length.out=10),
-	    seq(90,40,length.out=35),
-	    seq(40,10,length.out=10))
-probpres.ramp <- hcl(h = h, c = 80, l = l)
-
-
-###################################################
-### code chunk number 110: Ex4ProbabilitySurface
-###################################################
-opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)
-
-mapgrid.a <- raster(paste(MODELfn.a,"_map.img",sep=""))
-mapgrid.b <- raster(paste(MODELfn.b,"_map.img",sep=""))
-
-legend.subset<-c(100,80,60,40,20,1)
-legend.colors<-probpres.ramp[legend.subset]
-legend.label<-c("100%"," 80%"," 60%"," 40%"," 20%","  0%")
-
-image( mapgrid.a, 
-       col=probpres.ramp,
-       xlab="",ylab="",xaxt="n",yaxt="n",
-       zlim=c(0,1),
-       asp=1,bty="n",main="")
-mtext(response.name.a,side=3,line=1,cex=1.2)
-image(mapgrid.b, 
-      col=probpres.ramp,
-      xlab="",ylab="",xaxt="n",yaxt="n",
-      zlim=c(0,1),
-      asp=1,bty="n",main="")
-mtext(response.name.b,side=3,line=1,cex=1.2)
-
-legend( x=xmax(mapgrid.b),y=ymax(mapgrid.b),
-        legend=legend.label,
-        fill=legend.colors,
-        bty="n",
-        cex=1.2)
-				    
-mtext("Probability of Presence",side=3,line=1,cex=1.5,outer=T)
-par(opar)
-
-
-###################################################
-### code chunk number 111: Ex4ProductionMapsFig
-###################################################
-opar <- par(mfrow=c(1,2),mar=c(3,3,2,1),oma=c(0,0,3,4),xpd=NA)
-
-mapgrid.a <- raster(paste(MODELfn.a,"_map.img",sep=""))
-mapgrid.b <- raster(paste(MODELfn.b,"_map.img",sep=""))
-
-legend.subset<-c(100,80,60,40,20,1)
-legend.colors<-probpres.ramp[legend.subset]
-legend.label<-c("100%"," 80%"," 60%"," 40%"," 20%","  0%")
-
-image( mapgrid.a, 
-       col=probpres.ramp,
-       xlab="",ylab="",xaxt="n",yaxt="n",
-       zlim=c(0,1),
-       asp=1,bty="n",main="")
-mtext(response.name.a,side=3,line=1,cex=1.2)
-image(mapgrid.b, 
-      col=probpres.ramp,
-      xlab="",ylab="",xaxt="n",yaxt="n",
-      zlim=c(0,1),
-      asp=1,bty="n",main="")
-mtext(response.name.b,side=3,line=1,cex=1.2)
-
-legend( x=xmax(mapgrid.b),y=ymax(mapgrid.b),
-        legend=legend.label,
-        fill=legend.colors,
-        bty="n",
-        cex=1.2)
-				    
-mtext("Probability of Presence",side=3,line=1,cex=1.5,outer=T)
-par(opar)
-
-
-###################################################
-### code chunk number 112: Remove Rplots pdf
+### code chunk number 91: Remove Rplots pdf
 ###################################################
 dev.off()
 file.remove("Rplots.pdf")
